==> bacula-1.34.6.tar.gz: bacula-1.34.6/src/filed/win32/winres.h <==
/*
 * Included by bacula.rc
 */

/* Icon definitions */
#define IDI_BACULA                      100
#define IDI_IDLE                        101
#define IDI_RUNNING                     102
#define IDI_JOB_ERROR                   103
#define IDR_TRAYMENU                    104

#define IDC_LIST                        1000
#define IDC_NONYET_LABEL                1006
#define IDC_UPDATE_BORDER               1010
#define IDC_APCUPSDBMP                  1016
#define IDC_VERSION                     1017
#define IDC_NAME                        1018
#define IDC_EMAIL                       1019
#define IDC_WWW                         1022
#define IDC_COPYRIGHT                   1023
#define IDACCEPT                        1030
#define IDREJECT                        1031
#define IDC_STATIC_TEXT1                1032
#define IDC_ACCEPT_IP                   1033
#define IDC_STATIC_TEXT                 1034
#define IDC_ACCEPT_TIMEOUT              1035
#define IDC_TRADEMARK                   1036


#define ID_PROPERTIES                   40001
#define ID_CLOSE                        40002
#define ID_KILLCLIENTS                  40003
#define ID_ABOUT                        40004
#define ID_STATUS                       40005
#define ID_DEFAULT_PROPERTIES           40006
#define ID_EVENTS                       40007

/* Dialog definitions */
#define IDD_PROPERTIES                  200
#define IDD_ABOUT                       201
#define IDD_STATUS                      202
#define IDD_EVENTS                      203


#define IDB_BACULABMP                   106

==> bacula_1.38.11.orig.tar.gz: bacula-1.38.11/src/filed/win32/winres.h <==
/*
 * Included by bacula.rc
 */

/* Icon definitions */
#define IDI_BACULA                      100
#define IDI_IDLE                        101
#define IDI_RUNNING                     102
#define IDI_JOB_ERROR                   103
#define IDI_JOB_WARNING                 104
#define IDR_TRAYMENU                    105
#define IDB_BACULABMP                   106

#define IDC_LIST                        1000
#define IDC_NONYET_LABEL                1006
#define IDC_UPDATE_BORDER               1010
#define IDC_APCUPSDBMP                  1016
#define IDC_VERSION                     1017
#define IDC_NAME                        1018
#define IDC_EMAIL                       1019
#define IDC_WWW                         1022
#define IDC_COPYRIGHT                   1023
#define IDACCEPT                        1030
#define IDREJECT                        1031
#define IDC_STATIC_TEXT1                1032
#define IDC_ACCEPT_IP                   1033
#define IDC_STATIC_TEXT                 1034
#define IDC_ACCEPT_TIMEOUT              1035
#define IDC_TRADEMARK                   1036


#define ID_PROPERTIES                   40001
#define ID_CLOSE                        40002
#define ID_KILLCLIENTS                  40003
#define ID_ABOUT                        40004
#define ID_STATUS                       40005
#define ID_DEFAULT_PROPERTIES           40006
#define ID_EVENTS                       40007

/* Dialog definitions */
#define IDD_PROPERTIES                  200
#define IDD_ABOUT                       201
#define IDD_STATUS                      202
#define IDD_EVENTS                      203
